Command Line Interface
======================
e(BE:L) commands

.. click:: ebel.cli:validate
   :prog: Validate BEL file

.. click:: ebel.cli:repair
   :prog: Repair BEL file

.. click:: ebel.cli:import_json
   :prog: Import generated JSON

.. click:: ebel.cli:enrich
   :prog: Enrich BEL network

.. click:: ebel.cli:set_connection
   :prog: Set the sqlalchemy connection string

.. click:: ebel.cli:set_mysql
   :prog: Set the MySQL connection string

.. click:: ebel.cli:serve
   :prog: Run the e(BE:L) API server